@@ -1,5 +1,5 @@
 """Top-level package for Notebook-like Executables."""
 
 __author__ = """Matthias Hölzl"""
-__email__ = 'tc@xantira.com'
-__version__ = '0.2.1'
+__email__ = "tc@xantira.com"
+__version__ = "0.2.2"
